codeunit 50014 DynamicwebOrdersSubscriber
{
    EventSubscriberInstance = StaticAutomatic;

    var
        ElementHelper: Codeunit ElementHelper;
        DynamicwebXmlHelper: Codeunit DynamicwebXmlHelper;

    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebOrdersPublisher, 'OnBeforeExecutePutOrdersRequest', '', true, true)]
    procedure OnBeforeExecutePutOrdersRequest(var requestDoc: XmlDocument; var stopExecution: Boolean; var responseDoc: XmlDocument);
    begin
        ElementHelper.AddCustomElement('OnBeforeExecutePutOrdersRequest', responseDoc);
    end;

    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebOrdersPublisher, 'OnAfterExecutePutOrdersRequest', '', true, true)]
    procedure OnAfterExecutePutOrdersRequest(var requestDoc: XmlDocument; var responseDoc: XmlDocument);
    begin
        ElementHelper.AddCustomElement('OnAfterExecutePutOrdersRequest', responseDoc);
    end;

    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebOrdersPublisher, 'OnBeforeWriteNote', '', true, true)]
    procedure OnBeforeWriteNote(var noteText: Text; var skipWrittingNote: Boolean; salesHeader: Record "Sales Header");
    begin
        noteText := 'Custom note text';
    end;

    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebOrdersPublisher, 'OnBeforeCalculateOrderRequest', '', true, true)]
    procedure OnBeforeCalculateOrderRequest(var orderNode: XmlNode; var stopExecution: Boolean; var responseRootNode: XmlNode);
    begin
        ElementHelper.AddCustomElement('OnBeforeCalculateOrderRequest', responseRootNode);
    end;

    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebOrdersPublisher, 'OnAfterCalculateOrderRequest', '', true, true)]
    procedure OnAfterCalculateOrderRequest(var orderNode: XmlNode; var responseRootNode: XmlNode);
    begin
        ElementHelper.AddCustomElement('OnAfterCalculateOrderRequest', responseRootNode);
    end;

    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebOrdersPublisher, 'OnBeforeCreateOrderRequest', '', true, true)]
    procedure OnBeforeCreateOrderRequest(var orderNode: XmlNode; var stopExecution: Boolean; var responseRootNode: XmlNode);
    begin
        ElementHelper.AddCustomElement('OnBeforeCreateOrderRequest', responseRootNode);
    end;


    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebOrdersPublisher, 'OnAfterCreateOrderRequest', '', true, true)]
    procedure OnAfterCreateOrderRequest(var orderNode: XmlNode; var responseRootNode: XmlNode);
    begin
        ElementHelper.AddCustomElement('OnAfterCreateOrderRequest', responseRootNode);
    end;

    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebOrdersPublisher, 'OnBeforeUpdateSalesHeader', '', true, true)]
    procedure OnBeforeUpdateSalesHeader(var salesheader: Record "Sales Header"; orderRequestNode: XmlNode);
    begin
        salesheader."Sell-to Address" := 'extendable from OnBeforeUpdateSalesHeader';
    end;

    // [Obsolete('Use CreateOrderOnBeforeCreateSalesLine instead')]
    // [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebOrdersPublisher, 'OnBeforeCreateSalesLine', '', true, true)]
    // procedure OnBeforeCreateSalesLine(var salesline: Record "Sales Line"; var salesheader: Record "Sales Header"; requestDoc: XmlDocument; var requestOrderNode: XmlNode; var requestOrderLineNode: XmlNode);
    // begin
    //     salesline.Description := 'extendable from OnBeforeCreateSalesLine';
    // end;

    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebOrdersPublisher, 'OnBeforeAddSalesLineToResponse', '', true, true)]
    procedure OnBeforeAddSalesLineToResponse(var salesline: Record "Sales Line"; var salesheader: Record "Sales Header"; var dynamicwebDiscountId: Text; var dynamicwebDiscountName: Text; var cancelAdd: boolean);
    begin
        //Skip adding sales line with 1936-S product to response xml
        if (salesLine."No." = '1936-S') then
            cancelAdd := true;
    end;

    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebOrdersPublisher, 'OnAfterAddSalesLineToResponse', '', true, true)]
    procedure OnAfterAddSalesLineToResponse(var responseOrderLineXml: XmlNode; salesline: Record "Sales Line"; salesheader: Record "Sales Header");
    begin
        DynamicwebXmlHelper.AddField(responseOrderLineXml, 'OnAfterAddSalesLineToResponse', 'produced by the Dynamic Plugin Unit Example extension');
    end;

    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebOrdersPublisher, 'OnAfterAddBCOrderDiscountOrderLineToResponse', '', true, true)]
    procedure OnAfterAddBCOrderDiscountOrderLineToResponse(var responseOrderLineXml: XmlNode; salesheader: Record "Sales Header");
    begin
        DynamicwebXmlHelper.AddField(responseOrderLineXml, 'OnAfterAddBCOrderDiscountOrderLineToResponse', 'produced by the Dynamic Plugin Unit Example extension');
    end;

    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebOrdersPublisher, 'OnBeforeInsertDynamicwebShippingSalesLine', '', true, true)]
    procedure OnBeforeInsertDynamicwebShippingSalesLine(var salesline: Record "Sales Line"; var cancelAdd: Boolean);
    begin
        salesline."Description" := 'extendable from OnBeforeInsertDynamicwebShippingSalesLine';
    end;

    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebOrdersPublisher, 'OnAfterAddSalesHeaderToResponse', '', true, true)]
    procedure OnAfterAddSalesHeaderToResponse(var responseSalesHeaderXml: XmlNode; salesheader: Record "Sales Header");
    begin
        DynamicwebXmlHelper.AddField(responseSalesHeaderXml, 'OnAfterAddSalesHeaderToResponse', 'produced by the Dynamic Plugin Unit Example extension');
    end;

    /// <summary>
    /// Occurs before order is created
    /// </summary>
    /// <param name="XMLOrderNode"></param>
    /// <param name="customer"></param>
    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebOrdersPublisher, 'OnBeforeCreateOrder', '', true, true)]
    procedure OnBeforeCreateOrder(XMLOrderNode: XmlNode; var customer: record Customer);
    begin
        DynamicwebXmlHelper.AddField(XMLOrderNode, 'OnBeforeCreateOrder', 'produced by the Dynamic Plugin Unit Example extension');
    end;

    /// <summary>
    /// Occurs after order is created
    /// </summary>
    /// <param name="salesheader"></param>
    /// <param name="XMLOrderNode"></param>
    /// <param name="customer"></param>
    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebOrdersPublisher, 'OnAfterCreateOrder', '', true, true)]
    procedure OnAfterCreateOrder(var salesheader: record "Sales Header"; XMLOrderNode: XmlNode; var customer: record Customer);
    begin
        DynamicwebXmlHelper.AddField(XMLOrderNode, 'OnAfterCreateOrder', 'produced by the Dynamic Plugin Unit Example extension');
    end;

    /// <summary>
    /// Occurs in calculate order request before order lines are processed
    /// and after the sales header was set
    /// </summary>
    /// <param name="salesheader"></param>
    /// <param name="XMLOrderNode"></param>
    /// <param name="customer"></param>
    /// <param name="requestDoc"></param>
    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebOrdersPublisher, 'CalculateOrderOnBeforeSetSalesLines', '', true, true)]
    procedure CalculateOrderOnBeforeSetSalesLines(var salesheader: record "Sales Header"; XMLOrderNode: XmlNode; var customer: record Customer; var requestDoc: XmlDocument)
    begin
        DynamicwebXmlHelper.AddField(XMLOrderNode, 'CalculateOrderOnBeforeSetSalesLines', 'produced by the Dynamic Plugin Unit Example extension');
    end;

    /// <summary>
    /// Occurs after calculate order method is processed    
    /// </summary>
    /// <param name="salesheader"></param>
    /// <param name="XMLOrderNode"></param>
    /// <param name="customer"></param>
    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebOrdersPublisher, 'OnAfterCalculateOrder', '', true, true)]
    procedure OnAfterCalculateOrder(var salesheader: record "Sales Header"; XMLOrderNode: XmlNode; var customer: record Customer)
    begin
        DynamicwebXmlHelper.AddField(XMLOrderNode, 'OnAfterCalculateOrder', 'produced by the Dynamic Plugin Unit Example extension');
    end;

    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebOrdersPublisher, 'OnBeforeCalculateSalesLine', '', true, true)]
    procedure OnBeforeCalculateSalesLine(var isHandled: Boolean; var salesline: Record "Sales Line"; var item: Record Item;
        var Currency: Record Currency; var CurrencyFactor: Decimal; var GLSetup: Record "General Ledger Setup"; var uom: Text;
        var QtyPerUOM: Decimal; var useDynamicwebDiscount: Boolean; var customer: Record Customer; var VATPostingSetupVATPercent: decimal; var VATCalcType: Enum "Tax Calculation Type")
    begin
    end;

    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebOrdersPublisher, 'CalculateOrderOnBeforeAddSalesLine', '', true, true)]
    procedure CalculateOrderOnBeforeAddSalesLine(var salesline: Record "Sales Line"; var salesheader: Record "Sales Header"; requestDoc: XmlDocument; var requestOrderNode: XmlNode; var requestOrderLineNode: XmlNode;
        var useDynamicwebDiscount: Boolean; var cancelLineAdd: Boolean);
    begin
    end;

    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebOrdersPublisher, 'CreateOrderOnBeforeCreateSalesLine', '', true, true)]
    procedure CreateOrderOnBeforeCreateSalesLine(var salesline: Record "Sales Line"; var salesheader: Record "Sales Header"; requestDoc: XmlDocument; var requestOrderNode: XmlNode; var requestOrderLineNode: XmlNode;
        var useDynamicwebDiscount: Boolean; var itemNo: Text; var cancelLineAdd: Boolean);
    begin
    end;

    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebOrdersPublisher, 'CreateOrderOnAfterCreateSalesLine', '', true, true)]
    procedure CreateOrderOnAfterCreateSalesLine(var salesline: Record "Sales Line"; var salesheader: Record "Sales Header"; requestDoc: XmlDocument; var requestOrderNode: XmlNode; var requestOrderLineNode: XmlNode;
        var useDynamicwebDiscount: Boolean);
    begin
    end;
}