codeunit 50012 DynamicwebProductsSubscriber
{
    EventSubscriberInstance = StaticAutomatic;

    var
        ElementHelper: Codeunit ElementHelper;
        DynamicwebXmlHelper: Codeunit DynamicwebXmlHelper;

    /// <summary>
    /// Add custom field to the products xml
    /// </summary>
    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebProductsPublisher, 'OnAddProductXmlNode', '', true, true)]
    procedure OnAddProductXmlNode(var productNode: XmlNode; item: Record Item);
    var
        DynamicwebContext: Codeunit DynamicwebContext;
        requestDoc: XmlDocument;
    begin
        //Adds custom field ProductProfitPercent to the product xml node:
        //<column columnName="ProductProfitPercent"><![CDATA[99]]></column>
        DynamicwebXmlHelper.AddField(productNode, 'ProductProfitPercent', Format(item."Profit %"));

        //You can access the source xml request by this code:
        requestDoc := DynamicwebContext.GetRequest();
    end;

    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebProductsPublisher, 'OnBeforeGetProductGroupsRequest', '', true, true)]
    procedure OnBeforeGetProductGroupsRequest(var requestDoc: XmlDocument; var stopExecution: Boolean; var responseRootNode: XmlNode);
    begin
        ElementHelper.AddCustomElement('OnBeforeGetProductGroupsRequest', responseRootNode);
    end;

    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebProductsPublisher, 'OnAfterGetProductGroupsRequest', '', true, true)]
    procedure OnAfterGetProductGroupsRequest(var requestDoc: XmlDocument; var responseRootNode: XmlNode);
    begin
        ElementHelper.AddCustomElement('OnAfterGetProductGroupsRequest', responseRootNode);
    end;

    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebProductsPublisher, 'OnBeforeGetProductStockRequest', '', true, true)]
    procedure OnBeforeGetProductStockRequest(var requestDoc: XmlDocument; var stopExecution: Boolean; var responseRootNode: XmlNode);
    begin
        ElementHelper.AddCustomElement('OnBeforeGetProductStockRequest', responseRootNode);
    end;

    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebProductsPublisher, 'OnAfterGetProductStockRequest', '', true, true)]
    procedure OnAfterGetProductStockRequest(var requestDoc: XmlDocument; var responseRootNode: XmlNode);
    begin
        ElementHelper.AddCustomElement('OnAfterGetProductStockRequest', responseRootNode);
    end;

    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebProductsPublisher, 'OnBeforeGetProductsRequest', '', true, true)]
    procedure OnBeforeGetProductsRequest(var requestDoc: XmlDocument; var stopExecution: Boolean; var responseRootNode: XmlNode);
    begin
        ElementHelper.AddCustomElement('OnBeforeGetProductsRequest', responseRootNode);
    end;

    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebProductsPublisher, 'OnAfterGetProductsRequest', '', true, true)]
    procedure OnAfterGetProductsRequest(var requestDoc: XmlDocument; var responseRootNode: XmlNode);
    begin
        ElementHelper.AddCustomElement('OnAfterGetProductsRequest', responseRootNode);
    end;

    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebProductsPublisher, 'OnBeforeGetProductInfoRequest', '', true, true)]
    procedure OnBeforeGetProductInfoRequest(var requestDoc: XmlDocument; var stopExecution: Boolean; var responseRootNode: XmlNode);
    begin
        ElementHelper.AddCustomElement('OnBeforeGetProductInfoRequest', responseRootNode);
    end;

    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebProductsPublisher, 'OnAfterGetProductInfoRequest', '', true, true)]
    procedure OnAfterGetProductInfoRequest(var requestDoc: XmlDocument; var responseRootNode: XmlNode);
    begin
        ElementHelper.AddCustomElement('OnAfterGetProductInfoRequest', responseRootNode);
    end;

    /// <summary>
    /// Add custom field to the product info xml
    /// </summary>
    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebProductsPublisher, 'OnAddProductInfoXmlNode', '', true, true)]
    procedure OnAddProductInfoXmlNode(var productNode: XmlNode; item: Record Item; customer: Record Customer);
    var
        attributes: XmlAttributeCollection;
        pXmlElement: XmlElement;

        DynamicwebContext: Codeunit DynamicwebContext;
        requestDoc: XmlDocument;
    begin
        pXmlElement := XmlElement.Create('dummy');
        attributes := pXmlElement.Attributes();
        attributes.Set('columnName', 'OnAddProductInfoXmlNode');
        ElementHelper.AddCustomElement('column', 'customValue', attributes, productNode);

        //You can access the source xml request by this code:
        requestDoc := DynamicwebContext.GetRequest();
    end;

    /// <summary>
    /// This event runs in the /GetEcomData/tables/Products/@type=all request before Items records are enumerated
    /// You can filter item records in this subscriber per your needs
    /// </summary>
    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebProductsPublisher, 'OnBeforeFindItems', '', true, true)]
    procedure OnBeforeFindItems(var item: Record Item; var requestDoc: XmlDocument);
    begin
        //item.SETFILTER("No.", '>%1', Format(1000));
    end;

    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebProductsPublisher, 'OnAddItemCustomerOnBeforeFindItemPrice', '', true, true)]
    procedure OnAddItemCustomerOnBeforeFindItemPrice(var item: Record Item; var qtyPerUOM: Decimal; var quantity: Decimal; requestXmlNode: XmlNode);
    begin
    end;

    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebProductsPublisher, 'OnAddItemCustomerOnBeforeAddItemUOM', '', true, true)]
    procedure OnAddItemCustomerOnBeforeAddItemUOM(var item: Record Item; var xmlNode: XmlNode; requestXmlNode: XmlNode);
    begin
        DynamicwebXmlHelper.AddOrUpdateFieldValue(xmlNode, 'ProductIdentifier', 'ProducedByExampleExtension');
        DynamicwebXmlHelper.AddField(xmlNode, 'TestColumn', 'ColumnProducedByExampleExtension');
    end;

    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebProductsPublisher, 'OnBeforeFindItemPriceOld', '', true, true)]
    procedure OnBeforeFindItemPriceOld(var isHandled: Boolean;
        var item: Record Item; var customer: Record Customer;
        var VATPostingSetup: Record "VAT Posting Setup"; var Currency: Record Currency; var CurrencyFactor: Decimal;
        var ExchRateDate: Date; var GLSetup: Record "General Ledger Setup";
        var itemUOMCode: Code[10]; var QtyPerUOM: decimal; var qty: Decimal; var variant: Text;
        requestXmlNode: XmlNode; var priceToReturn: Decimal);
    begin
    end;

    [EventSubscriber(ObjectType::Codeunit, Codeunit::DynamicwebProductsPublisher, 'OnBeforeFindItemPrice', '', true, true)]
    procedure OnBeforeFindItemPrice(var isHandled: Boolean;
        var item: Record Item; var customer: Record Customer; var variant: Text;
        var Currency: Record Currency; var CurrencyFactor: Decimal; var ExchRateDate: Date;
        var itemUOMCode: Code[10]; var QtyPerUOM: decimal; var qty: Decimal; var VATCalcType: Enum "Tax Calculation Type";
        requestXmlNode: XmlNode; var priceToReturn: Decimal);
    begin
    end;
}